/// \file    ArgoNeuTRecoBaseDrawer.h
/// \brief   Class to aid in the rendering of ArgoNeuT Reconstruction objects
/// \author  msoderbe@syr.edu
#ifndef EVD_ARGONEUTRECOBASEDRAWER_H
#define EVD_ARGONEUTRECOBASEDRAWER_H
#include "lareventdisplay/EventDisplay/RecoBaseDrawer.h"
#include <vector>

#include "canvas/Persistency/Common/PtrVector.h"

#ifdef __ROOTCLING__
namespace art { 
  class Event;
}
#else
#include "art/Framework/Principal/Event.h"
#endif

namespace t962     { class MINOS; }

namespace argoevd {
  /// Aid in the rendering of ArgoNeuT Reconstruction objects
   class ArgoneutRecoBaseDrawer : public evd::RecoBaseDrawer {
  public:
    ArgoneutRecoBaseDrawer();
    ~ArgoneutRecoBaseDrawer();

  public:

    void ArgoSpacePoint(std::vector<const recob::SpacePoint*> sps,
                         int                 id,
                         evdb::View3D*       view,
                         bool matched=false,
                         float charge=-999.);
     
     void ArgoProng3D(const art::Event& evt,
                      evdb::View3D*     view);

    
  private:

    int GetArgoTracks(const art::Event&                 evt,
                      const std::string&                which,
                      art::PtrVector<recob::Track>&     track);
    int GetArgoShowers(const art::Event&                evt,
		       const std::string&               which,
		       art::PtrVector<recob::Shower>&   shower);


     int GetMinos(const art::Event&            evt,
                  const std::string&           which,
                  art::PtrVector<t962::MINOS>& minos);


    
        
    
    
  };
}

#endif
////////////////////////////////////////////////////////////////////////
